summaryrefslogtreecommitdiff
path: root/SmartDeviceLink/SDLH264Packetizer.h
diff options
context:
space:
mode:
authorSho Amano <samano@xevo.com>2017-08-28 20:25:05 +0900
committerSho Amano <samano@xevo.com>2017-08-28 20:43:08 +0900
commit107382ff40ed37c794096cd9740d0ce079b01a06 (patch)
tree9ea9cc564afa1458859dab2c7b1cd5aa399b45b1 /SmartDeviceLink/SDLH264Packetizer.h
parentafecd283f0e65c47e43d9d47c67753575caeb675 (diff)
downloadsdl_ios-107382ff40ed37c794096cd9740d0ce079b01a06.tar.gz
Reflect code review comments
- Update "note" comment to "warning" - Add generics to NSArray containers - rename "pts" arg to "presentationTimestamp" - remove redundant method declarations - remove redundant protocol conformations
Diffstat (limited to 'SmartDeviceLink/SDLH264Packetizer.h')
-rw-r--r--SmartDeviceLink/SDLH264Packetizer.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/SmartDeviceLink/SDLH264Packetizer.h b/SmartDeviceLink/SDLH264Packetizer.h
index 8635cdd16..45c5e8d5c 100644
--- a/SmartDeviceLink/SDLH264Packetizer.h
+++ b/SmartDeviceLink/SDLH264Packetizer.h
@@ -16,15 +16,17 @@ NS_ASSUME_NONNULL_BEGIN
* Creates packets from given H.264 NAL units and presentation timestamp.
*
* @param nalUnits List of NAL units to create packets.
* @param pts Presentation timestamp associated to the NAL units, in seconds.
*
* @return List of NSData. Each NSData holds a packet.
*
- * @note This method cannot be called more than once with same pts value.
- * All NAL units that belongs to a frame should be included in
- * nalUnits array.
+ * @warning This method cannot be called more than once with same pts value.
+ * All NAL units that belongs to a frame should be included in
+ * nalUnits array.
*/
-- (nullable NSArray *)createPackets:(NSArray *)nalUnits pts:(double)pts;
+- (nullable NSArray<NSData *> *)createPackets:(NSArray<NSData *> *)nalUnits
+ presentationTimestamp:(double)presentationTimestamp;
@end
@@ -16,15 +16,17 @@ NS_ASSUME_NONNULL_BEGIN
*
* @param nalUnits List of NAL units to create packets.
- * @param pts Presentation timestamp associated to the NAL units, in seconds.
+ * @param presentationTimestamp Presentation timestamp associated to
+ * the NAL units, in seconds.
*
* @return List of NSData. Each NSData holds a packet.